@@ -1,9 +1,12 @@
 from .lineage_population_model import *
 from .embryo_generator_model import *
 from .embryo_segmentor import *
+from .tests import test ## tests/test.py/<class test()>
 
-__version__ = "0.1.7"
+__version__ = "0.2.0"
 
+## folder names below
 __all__ = ["lineage_populaton_model",
             "embryo_generator_model",
-            "embryo_segmentor"]
\ No newline at end of file
+            "embryo_segmentor",
+            "tests"]
\ No newline at end of file
